# Changelog

[Also available through GitHub interface](https://github.com/punch-mission/thuban/releases)

## Version 0.0.8: June 4, 2025

- Minor hotfix changes

## Version 0.0.7: May 22, 2025

- allow PV to vary in fitting

## Version 0.0.6: May 22, 2025

* specify codecov path by @jmbhughes in https://github.com/punch-mission/thuban/pull/18
* Update issue templates by @jmbhughes in https://github.com/punch-mission/thuban/pull/19
* Support more PUNCH features in https://github.com/punch-mission/thuban/pull/25

## Version 0.0.5: Nov 13, 2024

- Fix version names in docs by @jmbhughes in #12
- add tolerances by @jmbhughes in #13
- [pre-commit.ci] pre-commit autoupdate by @pre-commit-ci in #14

## Version 0.0.4: Nov 1, 2024

- Add pinned environment ci by @jmbhughes in #10
- Create .readthedocs.yaml by @jmbhughes in #11

## Version 0.0.3: Aug 24, 2024

- incorporates masking and pv by @jmbhughes in #8

## Version 0.0.2: Aug 18, 2024

- add file manifest by @jmbhughes in #7

## Version 0.0.1: Aug 18, 2024

Initial release
